The branch, master has been updated
       via  cc248f7dfccf015586627ecef5fc5a475cc7f842 (commit)
      from  2a3270beec2800e0a5dcb69af111d053abaa9245 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit cc248f7dfccf015586627ecef5fc5a475cc7f842
Author: Michael Adam <ob...@samba.org>
Date:   Wed Aug 26 12:58:47 2009 +0200

    util: fix comment and clarify argument name in DLIST_DEMOTE()
    
    Michael

-----------------------------------------------------------------------

Summary of changes:
 lib/util/dlinklist.h |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)


Changeset truncated at 500 lines:

diff --git a/lib/util/dlinklist.h b/lib/util/dlinklist.h
index 1a4ebb6..693b43d 100644
--- a/lib/util/dlinklist.h
+++ b/lib/util/dlinklist.h
@@ -87,11 +87,11 @@ do { \
        }\
 } while (0)
 
 /* demote an element to the end of the list, needs a tmp pointer */
 #define DLIST_DEMOTE(list, p, tmp) \
 do { \
                DLIST_REMOVE(list, p); \
-               DLIST_ADD_END(list, p, tmp); \
+               DLIST_ADD_END(list, p, type); \
 } while (0)
 
 /* concatenate two lists - putting all elements of the 2nd list at the
@@ -87,11 +87,11 @@ do { \
 } while (0)
 
-/* demote an element to the end of the list, needs a tmp pointer */
-#define DLIST_DEMOTE(list, p, tmp) \
+/* demote an element to the end of the list, needs the entry type */
+#define DLIST_DEMOTE(list, p, type) \
 do { \
                DLIST_REMOVE(list, p); \


-- 
Samba Shared Repository

Reply via email to